@@ -1,29 +1,18 @@
 /*
-  Copyright (c) 2014-2019 Montel Laurent <montel@kde.org>
+  SPDX-FileCopyrightText: 2014-2022 Laurent Montel <montel@kde.org>
 
-  This library is free software; you can redistribute it and/or
-  modify it under the terms of the GNU Lesser General Public
-  License as published by the Free Software Foundation; either
-  version 2.1 of the License, or (at your option) any later version.
-
-  This library is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Lesser General Public License for more details.
-
-  You should have received a copy of the GNU Lesser General Public
-  License along with this library; if not, write to the Free Software
-  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: LGPL-2.1-or-later
 */
 
 #include "grantleethemetest.h"
 #include "grantleetheme.h"
 
-#include <qtest.h>
-#include <QDir>
+#include <QFile>
 #include <QPalette>
 #include <QProcess>
+#include <QRegularExpression>
 #include <QStandardPaths>
+#include <qtest.h>
 
 #include <KColorScheme>
 #include <KConfigGroup>
@@ -40,9 +29,7 @@ GrantleeThemeTest::GrantleeThemeTest(QObject *parent)
     qputenv("XDG_DATA_DIRS", GRANTLEETHEME_DATA_DIR);
 }
 
-GrantleeThemeTest::~GrantleeThemeTest()
-{
-}
+GrantleeThemeTest::~GrantleeThemeTest() = default;
 
 void GrantleeThemeTest::shouldHaveDefaultValue()
 {
@@ -82,11 +69,12 @@ void GrantleeThemeTest::shouldLoadTheme_data()
     QTest::addColumn<bool>("isvalid");
     QTest::addColumn<QStringList>("displayExtraVariables");
 
-    QTest::newRow("valid theme") <<  QStringLiteral("valid") << QStringLiteral("filename.testdesktop") << true << QStringList();
-    QTest::newRow("not existing theme") <<  QStringLiteral("notvalid") << QStringLiteral("filename.testdesktop") << false << QStringList();
+    QTest::newRow("valid theme") << QStringLiteral("valid") << QStringLiteral("filename.testdesktop") << true << QStringList();
+    QTest::newRow("not existing theme") << QStringLiteral("notvalid") << QStringLiteral("filename.testdesktop") << false << QStringList();
     QStringList extraVariables;
     extraVariables << QStringLiteral("foo") << QStringLiteral("bla");
-    QTest::newRow("valid with extra variable") <<  QStringLiteral("valid-with-extravariables") << QStringLiteral("filename.testdesktop") << true << extraVariables;
+    QTest::newRow("valid with extra variable") << QStringLiteral("valid-with-extravariables") << QStringLiteral("filename.testdesktop") << true
+                                               << extraVariables;
 }
 
 void GrantleeThemeTest::shouldLoadTheme()
@@ -96,7 +84,7 @@ void GrantleeThemeTest::shouldLoadTheme()
     QFETCH(bool, isvalid);
     QFETCH(QStringList, displayExtraVariables);
 
-    GrantleeTheme::Theme theme(QStringLiteral(GRANTLEETHEME_DATA_DIR "/themes/")  + dirname, dirname, filename);
+    GrantleeTheme::Theme theme(QStringLiteral(GRANTLEETHEME_DATA_DIR "/themes/") + dirname, dirname, filename);
     QCOMPARE(theme.isValid(), isvalid);
     QCOMPARE(theme.displayExtraVariables(), displayExtraVariables);
     QCOMPARE(theme.dirName(), dirname);
@@ -108,29 +96,24 @@ bool GrantleeThemeTest::validateHtml(const QString &themePath, const QString &na
     const QString htmlFileName = themePath + QStringLiteral("/%1.out.html").arg(name);
     QFile outFile(outFileName);
     if (!outFile.open(QIODevice::WriteOnly)) {
+        qDebug() << "impossible to open " << outFile.fileName();
         return false;
     }
     outFile.write(html.toUtf8());
     outFile.close();
 
-    // validate xml and pretty-print for comparisson
+    // validate xml and pretty-print for comparison
     // TODO add proper cmake check for xmllint and diff
-    const QStringList args = {
-        QStringLiteral("--format"),
-        QStringLiteral("--encode"),
-        QStringLiteral("UTF8"),
-        QStringLiteral("--output"),
-        htmlFileName,
-        outFileName
-    };
+    const QStringList args =
+        {QStringLiteral("--format"), QStringLiteral("--encode"), QStringLiteral("UTF8"), QStringLiteral("--output"), htmlFileName, outFileName};
 
     const int result = QProcess::execute(QStringLiteral("xmllint"), args);
     return result == 0;
 }
 
-bool GrantleeThemeTest::compareHtml(const QString &themePath, const QString &name)
+bool GrantleeThemeTest::compareHtml(const QString &generatedTheme, const QString &themePath, const QString &name)
 {
-    const QString htmlFileName = themePath + QStringLiteral("/%1.out.html").arg(name);
+    const QString htmlFileName = generatedTheme + QStringLiteral("/%1.out.html").arg(name);
     const QString referenceFileName = themePath + QStringLiteral("/%1_expected.html").arg(name);
 
     // get rid of system dependent or random paths
@@ -141,7 +124,7 @@ bool GrantleeThemeTest::compareHtml(const QString &themePath, const QString &nam
         }
         QString content = QString::fromUtf8(f.readAll());
         f.close();
-        content.replace(QRegExp(QLatin1String("\"file:[^\"]*[/(?:%2F)]([^\"/(?:%2F)]*)\"")), QStringLiteral("\"file:\\1\""));
+        content.replace(QRegularExpression(QLatin1String("\"file:[^\"]*[/(?:%2F)]([^\"/(?:%2F)]*)\"")), QStringLiteral("\"file:\\1\""));
         if (!f.open(QIODevice::WriteOnly | QIODevice::Truncate)) {
             return false;
         }
@@ -150,11 +133,7 @@ bool GrantleeThemeTest::compareHtml(const QString &themePath, const QString &nam
     }
 
     // compare to reference file
-    const QStringList args = {
-        QStringLiteral("-u"),
-        referenceFileName,
-        htmlFileName
-    };
+    const QStringList args = {QStringLiteral("-u"), referenceFileName, htmlFileName};
 
     QProcess proc;
     proc.setProcessChannelMode(QProcess::ForwardedChannels);
@@ -186,6 +165,8 @@ void GrantleeThemeTest::testRenderTemplate()
     QFETCH(QString, templateBasename);
 
     const QString themePath = QStringLiteral(GRANTLEETHEME_DATA_DIR "/themes/") + dirname;
+    const QString themeBinaryPath = QStringLiteral(GRANTLEETHEME_DATA_BUILD_DIR "/themes/") + dirname;
+    QDir().mkpath(themeBinaryPath);
 
     QVariantHash data;
     data[QStringLiteral("icon")] = QStringLiteral("kde");
@@ -208,11 +189,11 @@ void GrantleeThemeTest::testRenderTemplate()
     if (isValid) {
         const QString result = theme.render(templateBasename + QStringLiteral(".html"), data);
 
-        QVERIFY(validateHtml(themePath, templateBasename, result));
-        QVERIFY(compareHtml(themePath, templateBasename));
+        QVERIFY(validateHtml(themeBinaryPath, templateBasename, result));
+        QVERIFY(compareHtml(themeBinaryPath, themePath, templateBasename));
 
-        QFile::remove(themePath + QDir::separator() + templateBasename + QStringLiteral(".out"));
-        QFile::remove(themePath + QDir::separator() + templateBasename + QStringLiteral(".out.html"));
+        QFile::remove(themeBinaryPath + QLatin1Char('/') + templateBasename + QStringLiteral(".out"));
+        QFile::remove(themeBinaryPath + QLatin1Char('/') + templateBasename + QStringLiteral(".out.html"));
     }
 }
 
