@@ -1,24 +1,12 @@
 /*
-  Copyright (c) 2016-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "genericformatter.h"
-#include "grantleethemeengine.h"
 #include "grantleeki18nlocalizer.h"
+#include "grantleethemeengine.h"
 
 using namespace GrantleeTheme;
 
@@ -32,10 +20,15 @@ public:
 
     QString mThemePath;
     QString mDefaultMainFile;
-    std::unique_ptr<Engine> mEngine;
+    std::unique_ptr<Engine> const mEngine;
     QString mErrorMessage;
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     QSharedPointer<Grantlee::FileSystemTemplateLoader> mTemplateLoader;
     Grantlee::Template mTemplate;
+#else
+    QSharedPointer<KTextTemplate::FileSystemTemplateLoader> mTemplateLoader;
+    KTextTemplate::Template mTemplate;
+#endif
 };
 
 GenericFormatter::GenericFormatter(const QString &defaultHtmlMain, const QString &themePath)
@@ -64,7 +57,11 @@ void GenericFormatter::setDefaultHtmlMainFile(const QString &name)
 void GenericFormatter::setTemplatePath(const QString &path)
 {
     if (!d->mTemplateLoader) {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
         d->mTemplateLoader.reset(new Grantlee::FileSystemTemplateLoader);
+#else
+        d->mTemplateLoader.reset(new KTextTemplate::FileSystemTemplateLoader);
+#endif
     }
     d->mTemplateLoader->setTemplateDirs(QStringList() << path);
     d->mEngine->addTemplateLoader(d->mTemplateLoader);
@@ -84,7 +81,11 @@ QString GenericFormatter::errorMessage() const
 
 QString GenericFormatter::render(const QVariantHash &mapping) const
 {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     Grantlee::Context context(mapping);
+#else
+    KTextTemplate::Context context(mapping);
+#endif
     context.setLocalizer(d->mEngine->localizer());
 
     const QString contentHtml = d->mTemplate->render(&context);
